# DesktopClientGeneratedConfiguration

Contains the information generated by the system for a DesktopClientConfiguration. The `configuration_file` holds the contents of the file to use for configuration. Its type is described by `configuration_file_media_type`. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**desktop_resource_id** | **str** | The id of the desktop resource associated with this configuration. | 
**configuration_file** | **str** | The base64-encoded contents of the configuration file. The type of the file may change depending on the protocol used to communicate with the DesktopResource, or based on the desired client.  | 
**configuration_file_media_type** | **str** | How to interpreted the decoded contents of &#x60;configuration_file&#x60;. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


